# Table of Contents

- [workspace-views-configuration](<./workspace-views-configuration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Workspace Views Configuration](<./Workspace-Views-Configuration.md>)
  - [Overview](<./Workspace-Views-Configuration/Overview.md>)
  - [Scope](<./Workspace-Views-Configuration/Scope.md>)
  - [Difference Between Workspace Views and Virtual Workspaces](<./Workspace-Views-Configuration/Difference-Between-Workspace-Views-and-Virtual-Workspaces.md>)
  - [Creating and Managing Workspace Views](<./Workspace-Views-Configuration/Creating-and-Managing-Workspace-Views.md>)
  - [Creating a Workspace View](<./Workspace-Views-Configuration/Creating-a-Workspace-View.md>)
  - [Managing Workspace Views](<./Workspace-Views-Configuration/Managing-Workspace-Views.md>)
  - [Examples](<./Workspace-Views-Configuration/Examples.md>)
  - [Was this page helpful?](<./Workspace-Views-Configuration/Was-this-page-helpful.md>)
